==> munit-common-2.0.1-20180723.040411-269-sources.jar: org/mule/munit/common/model/DefaultTypedKeyValue.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.common.model;

import java.io.Serializable;

import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.Example;
import org.mule.runtime.extension.api.annotation.param.display.Placement;

/**
 * <p>
 * An abstract model that represents a key-value pair with mediaType and encoding
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public abstract class DefaultTypedKeyValue implements TypedKeyValue {

  @Parameter
  @Placement(order = 0)
  protected String key;

  @Parameter
  @Placement(order = 1)
  protected Serializable value;

  @Optional
  @Example("application/java")
  @Placement(order = 2)
  @Parameter
  protected String mediaType;

  @Optional
  @Example("UTF-8")
  @Placement(order = 3)
  @Parameter
  protected String encoding;

  public String getKey() {
    return key;
  }

  public void setKey(String key) {
    this.key = key;
  }

  public Serializable getValue() {
    return value;
  }

  public void setValue(Serializable value) {
    this.value = value;
  }

  public String getMediaType() {
    return mediaType;
  }

  public void setMediaType(String mediaType) {
    this.mediaType = mediaType;
  }

  public String getEncoding() {
    return encoding;
  }

  public void setEncoding(String encoding) {
    this.encoding = encoding;
  }

}

==> munit-common-2.3.9-sources.jar: org/mule/munit/common/model/DefaultTypedKeyValue.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.common.model;

import java.util.Objects;

import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.annotation.param.display.Example;
import org.mule.runtime.extension.api.annotation.param.display.Placement;


/**
 * <p>
 * An abstract model that represents a key-value pair with mediaType and encoding
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public abstract class DefaultTypedKeyValue implements TypedKeyValue {

  @Parameter
  @Placement(order = 0)
  protected String key;

  @Parameter
  @Placement(order = 1)
  protected Object value;

  @Optional
  @Example("application/java")
  @Placement(order = 2)
  @Parameter
  protected String mediaType;

  @Optional
  @Example("UTF-8")
  @Placement(order = 3)
  @Parameter
  protected String encoding;

  public String getKey() {
    return key;
  }

  public void setKey(String key) {
    this.key = key;
  }

  public Object getValue() {
    return value;
  }

  public void setValue(Object value) {
    this.value = value;
  }

  public String getMediaType() {
    return mediaType;
  }

  public void setMediaType(String mediaType) {
    this.mediaType = mediaType;
  }

  public String getEncoding() {
    return encoding;
  }

  public void setEncoding(String encoding) {
    this.encoding = encoding;
  }

  @Override
  public boolean equals(Object object) {
    if (!(object instanceof DefaultTypedKeyValue)) {
      return false;

    } else if (object == this) {
      return true;
    }

    DefaultTypedKeyValue that = (DefaultTypedKeyValue) object;

    return Objects.equals(this.getKey(), that.getKey()) &&
        Objects.equals(this.getValue(), that.getValue()) &&
        Objects.equals(this.getMediaType(), that.getMediaType()) &&
        Objects.equals(this.getEncoding(), that.getEncoding());
  }

  @Override
  public int hashCode() {
    return Objects.hash(getKey(), getValue(), getMediaType(), getEncoding());
  }
}
